@@ -61,9 +61,6 @@ class SQLCli(object):
     SQLMappingHandler = None
     SQLExecuteHandler = None
 
-    # 程序输出日志
-    logfile = None
-
     # 屏幕控制程序
     prompt_app = None
 
@@ -85,6 +82,7 @@ class SQLCli(object):
 
     # 屏幕输出
     Console = None             # 程序的控制台显示
+    logfile = None             # 程序输出日志文件
     HeadlessMode = False       # 没有显示输出，即不需要回显，用于子进程的显示
     logger = None              # 程序的输出日志
 
@@ -130,6 +128,7 @@ class SQLCli(object):
         self.SQLExecuteHandler.Console = self.Console
         self.SQLExecuteHandler.SQLPerfFile = self.m_SQLPerf
         self.SQLExecuteHandler.m_Worker_Name = WorkerName
+        self.SQLMappingHandler.Console = self.Console
 
         # 默认的输出格式
         self.formatter = TabularOutputFormatter(format_name='ascii')
@@ -1515,8 +1514,8 @@ class SQLCli(object):
         if not self.nologo:
             self.echo("SQLCli Release " + __version__)
 
-        # 如果运行在脚本方式下，不在调用PromptSession
-        # 调用PromptSession会导致程序在IDE下无法运行
+        # 如果运行在脚本方式下，不在调用PromptSession, 调用PromptSession会导致程序在IDE下无法运行
+        # 运行在无终端的模式下，也不会调用PromptSession, 调用PromptSession会导致程序出现Console错误
         # 对于脚本程序，在执行脚本完成后就会自动退出
         if self.sqlscript is None and not self.HeadlessMode:
             self.prompt_app = PromptSession()
@@ -1538,7 +1537,7 @@ class SQLCli(object):
             if self.sqlscript:
                 try:
                     self.DoSQL('start ' + self.sqlscript)
-                except (SQLCliException):
+                except SQLCliException:
                     m_runCli_Result = False
                     raise EOFError
                 self.DoSQL('exit')
